{% extends "admin/base_site.html" %}
{% load i18n admin_urls %}


{% block styles %}
  {{ block.super }}
  {{ media.css }}
{% endblock %}

{% block scripts %}
  {{ block.super }}
  {{ media.js }}
{% endblock %}

{% block bodyclass %}{{ block.super }} app-{{ opts.app_label }} model-{{ opts.model_name }} delete-confirmation{% endblock %}


{% block header %}
  {% if not is_popup %}
    {{ block.super }}
  {% endif %}
{% endblock %}


{% block breadcrumb_items %}
  <li class="breadcrumb-item">
    <a href="{% url 'admin:app_list' app_label=opts.app_label %}">{{ opts.app_config.verbose_name }}</a>
  </li>

  <li class="breadcrumb-item">
    <a href="{% url opts|admin_urlname:'changelist' %}">{{ opts.verbose_name_plural|capfirst }}</a>
  </li>

  <li class="breadcrumb-item">
    <a href="{% url opts|admin_urlname:'change' object.pk|admin_urlquote %}">{{ object|truncatewords:"18" }}</a>
  </li>

  <li class="breadcrumb-item active" aria-current="page">
    <span>{{ _("Delete") }}</span>
  </li>
{% endblock %}


{% block before_content %}{% endblock %}


{% block content %}
  <div class="paper-card paper-card--danger card">
    {% if perms_lacking %}
      <div class="card-body">
        <p>
          {% blocktrans with escaped_object=object %}Deleting the {{ object_name }} '{{ escaped_object }}' would result in deleting related objects, but your account doesn't have permission to delete the following types of objects:{% endblocktrans %}
        </p>

        <ul class="paper-object-list">
          {% for obj in perms_lacking %}
            <li>{{ obj }}</li>
          {% endfor %}
        </ul>
      </div>
    {% elif protected %}
      <div class="card-body">
        <p>
          {% blocktrans with escaped_object=object %}Deleting the {{ object_name }} '{{ escaped_object }}' would require deleting the following protected related objects:{% endblocktrans %}
        </p>

        <ul class="paper-object-list">
          {% for obj in protected %}
            <li>{{ obj }}</li>
          {% endfor %}
        </ul>
      </div>
    {% else %}
      <h1 class="card-header h3">
        {% url opts|admin_urlname:'change' object.pk|admin_urlquote as object_url %}
        {% blocktrans with escaped_object=object %}Are you sure you want to delete the {{ object_name }} "<a href="{{ object_url }}" target="_blank">{{ escaped_object }}</a>"?{% endblocktrans %}
      </h1>
      <div class="card-body">
        <p>
          {{ _("All of the following related items will be deleted:") }}
        </p>

        {% include "admin/includes/object_delete_summary.html" %}

        <h2 class="h3">
          {{ _("Objects") }}
        </h2>

        <ul class="paper-object-list">
          {{ deleted_objects|unordered_list }}
        </ul>

        <form method="post">
          {% csrf_token %}
          <input type="hidden" name="post" value="yes"/>

          {% if is_popup %}
            <input type="hidden" name="{{ is_popup_var }}" value="1"/>
          {% endif %}

          {% if to_field %}
            <input type="hidden" name="{{ to_field_var }}" value="{{ to_field }}"/>
          {% endif %}

          <button type="submit" class="btn btn-danger mr-3" autofocus>
            {{ _("Yes, I'm sure") }}
          </button>

          <button type="button" class="btn btn-outline-info back-button">
            {{ _("No, take me back") }}
          </button>
        </form>
      </div>
    {% endif %}
  </div>
{% endblock %}
