{% load load_paper i18n static %}{% load_paper as paper %}<!DOCTYPE html>
{% get_current_language as LANGUAGE_CODE %}{% get_current_language_bidi as LANGUAGE_BIDI %}
<html class="no-js" lang="{{ LANGUAGE_CODE|default:"en-us" }}" dir="{{ LANGUAGE_BIDI|yesno:'rtl,ltr,auto' }}">
<head>
  <meta charset="utf-8">

  <title>{% block title %}{% endblock %}</title>
  <meta http-equiv="content-type" content="text/html">
  <meta name="referrer" content="unsafe-url">
  <meta name="google" content="notranslate">
  <meta name="format-detection" content="telephone=no">
  <meta name="msapplication-tap-highlight" content="no">
  <meta name="SKYPE_TOOLBAR" content="SKYPE_TOOLBAR_PARSER_COMPATIBLE">
  {% block responsive %}
    <meta name="viewport" content="width=device-width, initial-scale=1.0, maximum-scale=1.0, user-scalable=no">
  {% endblock %}
  <meta name="theme-color" content="#3b91ca">
  {% block blockbots %}
    <meta name="robots" content="none,noarchive"/>
  {% endblock %}
  {% block meta %}{% endblock %}

  {# Favicon #}
  {% block favicon %}
    <link rel="icon" type="image/png" href="{% static paper.FAVICON %}">
  {% endblock %}

  {# CSS #}
  {% block styles %}
    {% include "paper_admin/app.head.html" %}
  {% endblock %}
  {% block extrastyle %}{% endblock %}

  {# Critical JS #}
  <script>
      document.documentElement.className = document.documentElement.className.replace(/\bno-js\b/, 'js');
  </script>

  {% block extrahead %}{% endblock %}
</head>
<body class="{{ is_popup|yesno:"popup," }} {% block bodyclass %}{% endblock %}"
      data-admin-utc-offset="{% now "Z" %}">
  {% if not is_popup %}
    {% block sidebar %}{% endblock %}
  {% endif %}

  <div class="paper-page d-flex flex-column min-vh-100">
    {% block header %}{% endblock %}

    {% if not is_popup %}
      {% spaceless %}{% block breadcrumbs %}{% endblock %}{% endspaceless %}
    {% endif %}

    <main class="d-flex flex-column flex-grow-1 py-3 mb-auto">
      {% block main %}{% endblock %}
    </main>

    {% block footer %}{% endblock %}
  </div>

  {% block scroll_top_button %}
    <div class="scroll-top-button" hidden>
      <i class="fa fa-chevron-up"></i>
    </div>
  {% endblock %}

  {% block scripts %}
    {% include "paper_admin/app.body.html" %}
  {% endblock %}
</body>
</html>
