"use strict";(self.webpackChunkpaper_admin=self.webpackChunkpaper_admin||[]).push([[2472],{7648:t=>{var n="Function.prototype.bind called on incompatible ",o=Array.prototype.slice,r=Object.prototype.toString,e="[object Function]";t.exports=function(t){var p=this;if("function"!=typeof p||r.call(p)!==e)throw new TypeError(n+p);for(var i,a=o.call(arguments,1),c=function(){if(this instanceof i){var n=p.apply(this,a.concat(o.call(arguments)));return Object(n)===n?n:this}return p.apply(t,a.concat(o.call(arguments)))},l=Math.max(0,p.length-a.length),u=[],s=0;s<l;s++)u.push("$"+s);if(i=Function("binder","return function ("+u.join(",")+"){ return binder.apply(this,arguments); }")(c),p.prototype){var y=function(){};y.prototype=p.prototype,i.prototype=new y,y.prototype=null}return i}},8612:(t,n,o)=>{var r=o(7648);t.exports=Function.prototype.bind||r}}]);
//# sourceMappingURL=npm.function-bind.96ed1aac8ae989a46fc0.js.map