<div{% include 'django/forms/widgets/attrs.html' %}>
  <a href="../password/" class="btn btn-sm btn-info">
    <i class="fa fa-pencil"></i><span>{{ _('Change password') }}</span>
  </a>

  <small class="d-block mt-1">
    {% for entry in summary %}
      <strong>{{ entry.label }}</strong>{% if entry.value %}: {{ entry.value }}{% endif %}
    {% endfor %}
  </small>
</div>
