<ul class="list-default">
  {% for group, options, index in widget.optgroups %}
    <li>
      {% if group %}{{ group }}{% endif %}
      {% for option in options %}
        {% with widget=option %}
          {% include option.template_name %}
        {% endwith %}
      {% endfor %}
    </li>
  {% endfor %}
</ul>