<footer class="paper-footer py-3 small text-secondary">
  <div class="container-fluid">
    <div class="row">
      <div class="col">

      </div>

      <div class="col-auto">
        <ul class="list-inline mb-0">
          <li class="list-inline-item">
            Django {{ paper.DJANGO_VERSION }}
          </li>
          <li class="list-inline-item">
            |
          </li>
          <li class="list-inline-item">
            Python {{ paper.PYTHON_VERSION }}
          </li>
          <li class="list-inline-item">
            |
          </li>
          <li class="list-inline-item">
            {{ paper.DB_VENDOR }} {{ paper.DB_VERSION }}
          </li>
        </ul>
      </div>
    </div>
  </div>
</footer>
