(self.webpackChunkpaper_admin=self.webpackChunkpaper_admin||[]).push([[3054],{5826:r=>{var a={}.toString;r.exports=Array.isArray||function(r){return"[object Array]"==a.call(r)}}}]);
//# sourceMappingURL=npm.isarray.78a169d9108c7b9665ff.js.map