"use strict";(self.webpackChunkpaper_admin=self.webpackChunkpaper_admin||[]).push([[331],{5320:t=>{var e,n,r=Function.prototype.toString,o="object"==typeof Reflect&&null!==Reflect&&Reflect.apply;if("function"==typeof o&&"function"==typeof Object.defineProperty)try{e=Object.defineProperty({},"length",{get:function(){throw n}}),n={},o((function(){throw 42}),null,e)}catch(t){t!==n&&(o=null)}else o=null;var c=/^\s*class\b/,u=function(t){try{var e=r.call(t);return c.test(e)}catch(t){return!1}},f=Object.prototype.toString,i="function"==typeof Symbol&&!!Symbol.toStringTag,l="object"==typeof document&&void 0===document.all&&void 0!==document.all?document.all:{};t.exports=o?function(t){if(t===l)return!0;if(!t)return!1;if("function"!=typeof t&&"object"!=typeof t)return!1;if("function"==typeof t&&!t.prototype)return!0;try{o(t,null,e)}catch(t){if(t!==n)return!1}return!u(t)}:function(t){if(t===l)return!0;if(!t)return!1;if("function"!=typeof t&&"object"!=typeof t)return!1;if("function"==typeof t&&!t.prototype)return!0;if(i)return function(t){try{return!u(t)&&(r.call(t),!0)}catch(t){return!1}}(t);if(u(t))return!1;var e=f.call(t);return"[object Function]"===e||"[object GeneratorFunction]"===e}}}]);
//# sourceMappingURL=npm.is-callable.d5a23d5735504fd52c9d.js.map