"""
Обновленная реализация автозаполнения slug-полей.
Исходная реализация добавляла CSS-класс "prepopulated_field" полям,
перечисленным в "prepopulated_fields_js". Это распространялось также
на шаблонную форму inline-формсетов. Из-за того, что в новой реализации
inline-формсетов шаблон формы (empty-form) хранится не напрямую
в DOM-дереве, а в <template>, это приводит к тому, что оригинальная
реализация автозаполнения не работает для динамически добавленных inline-форм.
"""
from . import helpers
