"use strict";(self.webpackChunkpaper_admin=self.webpackChunkpaper_admin||[]).push([[6112],{1044:(e,r,n)=>{var t=n(210)("%Object.defineProperty%",!0),u=function(){if(t)try{return t({},"a",{value:1}),!0}catch(e){return!1}return!1};u.hasArrayLengthDefineBug=function(){if(!u())return null;try{return 1!==t([],"length",{value:1}).length}catch(e){return!0}},e.exports=u}}]);
//# sourceMappingURL=npm.has-property-descriptors.c61958f077d69083ce66.js.map