{% extends "admin/change_form.html" %}
{% load i18n admin_urls %}


{% block breadcrumb_items %}
  <li class="breadcrumb-item">
    <a href="{% url 'admin:app_list' app_label=opts.app_label %}">{{ opts.app_config.verbose_name }}</a>
  </li>

  <li class="breadcrumb-item active" aria-current="page">
    {% if add %}
      {% blocktrans with name=opts.verbose_name %}Add {{ name }}{% endblocktrans %}
    {% else %}
      <span>{{ original|truncatewords:"18" }}</span>
    {% endif %}
  </li>
{% endblock breadcrumb_items %}
