{% if widget.is_hidden %}
  {% include "django/forms/widgets/hidden.html" %}
{% else %}
  <div class="url-field paper-input-group input-group">
    {% include "django/forms/widgets/input.html" %}

    <div class="input-group-append">
      <a class="url-field__link input-group-text"
         {% if widget.value %}href="{{ widget.value }}"{% endif %}
         target="_blank" rel="noopener" tabindex="-1"
         data-toggle="tooltip" data-placement="top" data-trigger="hover"
         data-html="true" title="{{ _('Visit URL') }}">
        <i class="fa fa-globe"></i>
      </a>
    </div>
  </div>
{% endif %}