/*!
 * ClockPicker v{package.version} for Bootstrap (http://weareoutman.github.io/clockpicker/)
 * Copyright 2014 Wang Shenwei.
 * Licensed under MIT (https://github.com/weareoutman/clockpicker/blob/gh-pages/LICENSE)
 */.clockpicker .input-group-addon{cursor:pointer}.clockpicker-moving{cursor:move}.clockpicker-align-left.popover>.arrow{left:25px}.clockpicker-align-top.popover>.arrow{top:17px}.clockpicker-align-right.popover>.arrow{left:auto;right:25px}.clockpicker-align-bottom.popover>.arrow{bottom:6px;top:auto}.clockpicker-popover .popover-title{background-color:#fff;color:#999;font-size:24px;font-weight:700;line-height:30px;text-align:center}.clockpicker-popover .popover-title span{cursor:pointer}.clockpicker-popover .popover-content{background-color:#f8f8f8;padding:12px}.popover-content:last-child{border-bottom-left-radius:5px;border-bottom-right-radius:5px}.clockpicker-plate{-webkit-touch-callout:none;background-color:#fff;border:1px solid #ccc;border-radius:50%;height:200px;overflow:visible;position:relative;-webkit-user-select:none;-khtml-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none;width:200px}.clockpicker-canvas,.clockpicker-dial{height:200px;left:-1px;position:absolute;top:-1px;width:200px}.clockpicker-minutes{visibility:hidden}.clockpicker-tick{border-radius:50%;color:#666;cursor:pointer;height:26px;line-height:26px;position:absolute;text-align:center;width:26px}.clockpicker-tick.active,.clockpicker-tick:hover{background-color:#c0e5f7;background-color:rgba(0,149,221,.25)}.clockpicker-button{background-color:#fff;background-image:none;border-top-left-radius:0;border-top-right-radius:0;border-width:1px 0 0;margin:0;padding:10px 0}.clockpicker-button:hover{background-color:#ebebeb;background-image:none}.clockpicker-button:focus{outline:none!important}.clockpicker-dial{-webkit-transition:-webkit-transform .35s,opacity .35s;-moz-transition:-moz-transform .35s,opacity .35s;-ms-transition:-ms-transform .35s,opacity .35s;-o-transition:-o-transform .35s,opacity .35s;transition:transform .35s,opacity .35s}.clockpicker-dial-out{opacity:0}.clockpicker-hours.clockpicker-dial-out{-webkit-transform:scale(1.2);-moz-transform:scale(1.2);-ms-transform:scale(1.2);-o-transform:scale(1.2);transform:scale(1.2)}.clockpicker-minutes.clockpicker-dial-out{-webkit-transform:scale(.8);-moz-transform:scale(.8);-ms-transform:scale(.8);-o-transform:scale(.8);transform:scale(.8)}.clockpicker-canvas{-webkit-transition:opacity 175ms;-moz-transition:opacity 175ms;-ms-transition:opacity 175ms;-o-transition:opacity 175ms;transition:opacity 175ms}.clockpicker-canvas-out{opacity:.25}.clockpicker-canvas-bearing,.clockpicker-canvas-fg{stroke:none;fill:#0095dd}.clockpicker-canvas-bg{stroke:none;fill:#c0e5f7}.clockpicker-canvas-bg-trans{fill:rgba(0,149,221,.25)}.clockpicker-canvas line{stroke:#0095dd;stroke-width:1;stroke-linecap:round}.clockpicker-button.am-button{margin:1px}.clockpicker-button.am-button,.clockpicker-button.pm-button{border:1px solid rgba(0,0,0,.2);border-radius:4px;padding:5px}.clockpicker-button.pm-button{margin:1px 1px 1px 136px}