"use strict";(self.webpackChunkpaper_admin=self.webpackChunkpaper_admin||[]).push([[9316],{1503:(r,t,e)=>{var n="function"==typeof Symbol&&"symbol"==typeof Symbol.iterator,o=e(4149),i=e(5320),u=e(8923),f=e(2636),l=function(r,t){if(null==r)throw new TypeError("Cannot call method on "+r);if("string"!=typeof t||"number"!==t&&"string"!==t)throw new TypeError('hint must be "string" or "number"');var e,n,u,f="string"===t?["toString","valueOf"]:["valueOf","toString"];for(u=0;u<f.length;++u)if(e=r[f[u]],i(e)&&(n=e.call(r),o(n)))return n;throw new TypeError("No default value")},a=function(r,t){var e=r[t];if(null!=e){if(!i(e))throw new TypeError(e+" returned for property "+t+" of object "+r+" is not a function");return e}};r.exports=function(r){if(o(r))return r;var t,e="default";if(arguments.length>1&&(arguments[1]===String?e="string":arguments[1]===Number&&(e="number")),n&&(Symbol.toPrimitive?t=a(r,Symbol.toPrimitive):f(r)&&(t=Symbol.prototype.valueOf)),void 0!==t){var i=t.call(r,e);if(o(i))return i;throw new TypeError("unable to convert exotic object to primitive")}return"default"===e&&(u(r)||f(r))&&(e="string"),l(r,"default"===e?"number":e)}},4149:r=>{r.exports=function(r){return null===r||"function"!=typeof r&&"object"!=typeof r}}}]);
//# sourceMappingURL=npm.es-to-primitive.931558c3950738ba337b.js.map