<div class="paper-filter">
  <p class="paper-filter__title mb-1">{{ title|capfirst }}</p>

  <ul class="list-default {{ classes }}">
    {% for choice in choices %}
      <li>
        <div class="custom-control custom-radio user-select-none">
          <input type="radio"
                 id="id_{{ spec.parameter_name }}-{{ choice.value }}"
                 value="{{ choice.value }}"
                 name="{{ spec.parameter_name }}"
                 class="custom-control-input"
                 {{ choice.selected|yesno:"checked," }}>
          <label class="custom-control-label" for="id_{{ spec.parameter_name }}-{{ choice.value }}">
            {{ choice.display }}
          </label>
        </div>
      </li>
    {% endfor %}
  </ul>
</div>