"use strict";(self.webpackChunkpaper_admin=self.webpackChunkpaper_admin||[]).push([[7637],{1924:(t,e,r)=>{var p=r(210),n=r(5559),a=n(p("String.prototype.indexOf"));t.exports=function(t,e){var r=p(t,!!e);return"function"==typeof r&&a(t,".prototype.")>-1?n(r):r}},5559:(t,e,r)=>{var p=r(8612),n=r(210),a=n("%Function.prototype.apply%"),o=n("%Function.prototype.call%"),l=n("%Reflect.apply%",!0)||p.call(o,a),c=n("%Object.getOwnPropertyDescriptor%",!0),u=n("%Object.defineProperty%",!0),i=n("%Math.max%");if(u)try{u({},"a",{value:1})}catch(t){u=null}t.exports=function(t){var e=l(p,o,arguments);if(c&&u){var r=c(e,"length");r.configurable&&u(e,"length",{value:1+i(0,t.length-(arguments.length-1))})}return e};var f=function(){return l(p,a,arguments)};u?u(t.exports,"apply",{value:f}):t.exports.apply=f}}]);
//# sourceMappingURL=npm.call-bind.c2052ffe5ce008c4633c.js.map