"use strict";(self.webpackChunkpaper_admin=self.webpackChunkpaper_admin||[]).push([[6148],{8987:(e,t,r)=>{var n;if(!Object.keys){var o=Object.prototype.hasOwnProperty,c=Object.prototype.toString,l=r(1414),i=Object.prototype.propertyIsEnumerable,a=!i.call({toString:null},"toString"),u=i.call((function(){}),"prototype"),p=["toString","toLocaleString","valueOf","hasOwnProperty","isPrototypeOf","propertyIsEnumerable","constructor"],f=function(e){var t=e.constructor;return t&&t.prototype===e},s={$applicationCache:!0,$console:!0,$external:!0,$frame:!0,$frameElement:!0,$frames:!0,$innerHeight:!0,$innerWidth:!0,$onmozfullscreenchange:!0,$onmozfullscreenerror:!0,$outerHeight:!0,$outerWidth:!0,$pageXOffset:!0,$pageYOffset:!0,$parent:!0,$scrollLeft:!0,$scrollTop:!0,$scrollX:!0,$scrollY:!0,$self:!0,$webkitIndexedDB:!0,$webkitStorageInfo:!0,$window:!0},y=function(){if("undefined"==typeof window)return!1;for(var e in window)try{if(!s["$"+e]&&o.call(window,e)&&null!==window[e]&&"object"==typeof window[e])try{f(window[e])}catch(e){return!0}}catch(e){return!0}return!1}();n=function(e){var t=null!==e&&"object"==typeof e,r="[object Function]"===c.call(e),n=l(e),i=t&&"[object String]"===c.call(e),s=[];if(!t&&!r&&!n)throw new TypeError("Object.keys called on a non-object");var b=u&&r;if(i&&e.length>0&&!o.call(e,0))for(var h=0;h<e.length;++h)s.push(String(h));if(n&&e.length>0)for(var g=0;g<e.length;++g)s.push(String(g));else for(var w in e)b&&"prototype"===w||!o.call(e,w)||s.push(String(w));if(a)for(var $=function(e){if("undefined"==typeof window||!y)return f(e);try{return f(e)}catch(e){return!1}}(e),j=0;j<p.length;++j)$&&"constructor"===p[j]||!o.call(e,p[j])||s.push(p[j]);return s}}e.exports=n},2215:(e,t,r)=>{var n=Array.prototype.slice,o=r(1414),c=Object.keys,l=c?function(e){return c(e)}:r(8987),i=Object.keys;l.shim=function(){if(Object.keys){var e=function(){var e=Object.keys(arguments);return e&&e.length===arguments.length}(1,2);e||(Object.keys=function(e){return o(e)?i(n.call(e)):i(e)})}else Object.keys=l;return Object.keys||l},e.exports=l},1414:e=>{var t=Object.prototype.toString;e.exports=function(e){var r=t.call(e),n="[object Arguments]"===r;return n||(n="[object Array]"!==r&&null!==e&&"object"==typeof e&&"number"==typeof e.length&&e.length>=0&&"[object Function]"===t.call(e.callee)),n}}}]);
//# sourceMappingURL=npm.object-keys.9301bdff3d5461ebc8f6.js.map