{% extends "admin/base_site.html" %}


{% block messages %}
  {{ block.super }}

  <li class="paper-message paper-message--error">
    {{ _("Something's wrong with your database installation. Make sure the appropriate database tables have been created, and make sure the database is readable by the appropriate user.") }}
  </li>
{% endblock %}
