{% extends "admin/object_history.html" %}
{% load admin_urls %}


{% block breadcrumb_items %}
  <li class="breadcrumb-item">
    <a href="{% url 'admin:app_list' app_label=opts.app_label %}">{{ opts.app_config.verbose_name }}</a>
  </li>

  <li class="breadcrumb-item">
    <a href="{% url opts|admin_urlname:'change' object.pk|admin_urlquote %}">{{ object|truncatewords:"18" }}</a>
  </li>

  <li class="breadcrumb-item active" aria-current="page">
    <span>{{ _("History") }}</span>
  </li>
{% endblock breadcrumb_items %}
