{% if show and choices %}
  <ul class="list-inline mb-0">
    {% block date-hierarchy-toplinks %}
      {% block date-hierarchy-back %}
        {% if back %}
          <li class="date-back list-inline-item">
            <a href="{{ back.link }}">&lsaquo; {{ back.title }}</a>
          </li>
        {% endif %}
      {% endblock %}

      {% block date-hierarchy-choices %}
        {% for choice in choices %}
          <li class="list-inline-item">
            {% if choice.link %}
              <a href="{{ choice.link }}">
            {% endif %}

            {{ choice.title }}

            {% if choice.link %}
              </a>
            {% endif %}
          </li>
        {% endfor %}
      {% endblock %}
    {% endblock %}
  </ul>
{% endif %}
