"use strict";(self.webpackChunkpaper_admin=self.webpackChunkpaper_admin||[]).push([[267],{9981:(t,e,r)=>{var n=String.prototype.valueOf,p=Object.prototype.toString,c=r(3695)();t.exports=function(t){return"string"==typeof t||"object"==typeof t&&(c?function(t){try{return n.call(t),!0}catch(t){return!1}}(t):"[object String]"===p.call(t))}}}]);
//# sourceMappingURL=npm.is-string.2c5ad41e766efc812e42.js.map