{% extends "admin/base_site.html" %}
{% load i18n l10n admin_urls %}


{% block styles %}
  {{ block.super }}
  {{ media.css }}
{% endblock %}

{% block scripts %}
  {{ block.super }}
  {{ media.js }}
{% endblock %}

{% block bodyclass %}{{ block.super }} app-{{ opts.app_label }} model-{{ opts.model_name }} delete-confirmation delete-selected-confirmation{% endblock %}


{% block breadcrumb_items %}
  <li class="breadcrumb-item">
    <a href="{% url 'admin:app_list' app_label=opts.app_label %}">{{ opts.app_config.verbose_name }}</a>
  </li>

  <li class="breadcrumb-item">
    <a href="{% url opts|admin_urlname:'changelist' %}">{{ opts.verbose_name_plural|capfirst }}</a>
  </li>

  <li class="breadcrumb-item active" aria-current="page">
    <span>{{ _("Delete multiple objects") }}</span>
  </li>
{% endblock %}


{% block before_content %}{% endblock %}


{% block content %}
  <div class="paper-card paper-card--danger card">
    {% if perms_lacking %}
      <div class="card-body">
        <p>
          {% blocktrans %}Deleting the selected {{ objects_name }} would result in deleting related objects, but your account doesn't have permission to delete the following types of objects:{% endblocktrans %}
        </p>

        <ul class="paper-object-list">
          {% for obj in perms_lacking %}
            <li>{{ obj }}</li>
          {% endfor %}
        </ul>
      </div>
    {% elif protected %}
      <div class="card-body">
        <p>
          {% blocktrans %}Deleting the selected {{ objects_name }} would require deleting the following protected related objects:{% endblocktrans %}
        </p>

        <ul class="paper-object-list">
          {% for obj in protected %}
            <li>{{ obj }}</li>
          {% endfor %}
        </ul>
      </div>
    {% else %}
      <h1 class="card-header h3">
        {% blocktrans %}Are you sure you want to delete the selected {{ objects_name }}?{% endblocktrans %}
      </h1>
      <div class="card-body">
        <p>
          {{ _("All of the following objects and their related items will be deleted:") }}
        </p>

        {% include "admin/includes/object_delete_summary.html" %}

        <h2 class="h3">
          {{ _("Objects") }}
        </h2>

        {% for deletable_object in deletable_objects %}
          <ul class="paper-object-list">
            {{ deletable_object|unordered_list }}
          </ul>
        {% endfor %}

        <form method="post">
          {% csrf_token %}
          <input type="hidden" name="post" value="yes"/>

          {% for obj in queryset %}
            <input type="hidden" name="{{ action_checkbox_name }}" value="{{ obj.pk|unlocalize }}"/>
          {% endfor %}

          <input type="hidden" name="action" value="delete_selected"/>

          <button type="submit" class="btn btn-danger mr-3" autofocus>
            {{ _("Yes, I'm sure") }}
          </button>

          <button type="button" class="btn btn-outline-info back-button">
            {{ _("No, take me back") }}
          </button>
        </form>
      </div>
    {% endif %}
  </div>
{% endblock %}
