{% extends "admin/base_site.html" %}

{% block bodyclass %}{{ block.super }} app-{{ opts.app_label }} model-{{ opts.model_name }} change-form{% endblock %}


{% block breadcrumb_items %}
  <li class="breadcrumb-item active" aria-current="page">
    {{ _("Password reset") }}
  </li>
{% endblock breadcrumb_items %}


{% block content_title %}
  <h1>
    {{ title }}
  </h1>
{% endblock %}


{% block content %}
  <form class="paper-form paper-form--hook" method="post" novalidate>
    {% csrf_token %}

    {% block form_top %}{% endblock %}

    <fieldset class="paper-card paper-card--info card mb-3">
      <p class="card-header">
        {{ _("Forgotten your password? Enter your email address below, and we'll email instructions for setting a new one.") }}
      </p>
      <div class="card-body p-0">
        {% include 'paper_admin/includes/admin_field.html' with field=form.email %}
      </div>
    </fieldset>

    <button type="submit" class="btn btn-success">
      {{ _("Reset my password") }}
    </button>
  </form>
{% endblock %}
