<form method="get" id="changelist-search" class="paper-search-form">
  <div class="paper-search-form__field">
    <div class="paper-search-form__icon">
      <i class="fa fa-search"></i>
    </div>
    <input type="search" name="{{ search_var }}" value="{{ cl.query }}"
           class="form-control"
           size="24" placeholder="{{ cl.search_help_text|default:_("Search") }}"
           id="searchbar" aria-label="{{ cl.search_help_text|default:_("Search") }}">
  </div>

  {% for pair in cl.params.items %}
    {% if pair.0 != search_var %}
      <input type="hidden" name="{{ pair.0 }}" value="{{ pair.1 }}"/>
    {% endif %}
  {% endfor %}
</form>
