{% extends "admin/base_site.html" %}


{% block breadcrumb_items %}
  <li class="breadcrumb-item active" aria-current="page">
    {{ _("Password reset") }}
  </li>
{% endblock breadcrumb_items %}


{% block content_title %}
  <h1>
    {{ title }}
  </h1>
{% endblock %}


{% block content %}
  <p class="paper-message paper-message--success">
    {{ _("We've emailed you instructions for setting your password, if an account exists with the email you entered. You should receive them shortly.") }}
    <br>
    {{ _("If you don't receive an email, please make sure you've entered the address you registered with, and check your spam folder.") }}
  </p>

  <a href="{% url 'admin_password_reset' %}" class="btn btn-success">
    {{ _("Go back") }}
  </a>
{% endblock %}
