<h2 class="h3">{{ _("Summary") }}</h2>

<ul class="paper-object-list">
  {% for model_name, object_count in model_count %}
    <li>{{ model_name|capfirst }}: {{ object_count }}</li>
  {% endfor %}
</ul>
