(self.webpackChunkpaper_admin=self.webpackChunkpaper_admin||[]).push([[7042],{2284:()=>{if(/add\/?$/.test(window.location.pathname)){const e=document.querySelector(".paper-form");if(e){const n=e.querySelector("input:not([type=hidden]), select, textarea");n&&n.focus()}}document.addEventListener("keydown",(function(e){27===e.which&&window.close()})),document.addEventListener("click",(function(e){e.target.closest(".cancel-link")&&(e.preventDefault(),window.close())}))}}]);
//# sourceMappingURL=popup.f41281a85a1bea03e1f1.js.map