"use strict";(self.webpackChunkpaper_admin=self.webpackChunkpaper_admin||[]).push([[606],{4289:(e,t,o)=>{var r=o(2215),n="function"==typeof Symbol&&"symbol"==typeof Symbol("foo"),p=Object.prototype.toString,a=Array.prototype.concat,c=Object.defineProperty,l=o(1044)(),i=c&&l,b=function(e,t,o,r){var n;(!(t in e)||"function"==typeof(n=r)&&"[object Function]"===p.call(n)&&r())&&(i?c(e,t,{configurable:!0,enumerable:!1,value:o,writable:!0}):e[t]=o)},f=function(e,t){var o=arguments.length>2?arguments[2]:{},p=r(t);n&&(p=a.call(p,Object.getOwnPropertySymbols(t)));for(var c=0;c<p.length;c+=1)b(e,p[c],t[p[c]],o[p[c]])};f.supportsDescriptors=!!i,e.exports=f}}]);
//# sourceMappingURL=npm.define-properties.d3b018b02d33610355ea.js.map