{% load i18n %}

<h4>
  {% blocktrans %}We received a request to reset your password at {{ site_name }}{% endblocktrans %}
</h4>

<p>
  {{ _("Use the link below to set up a new password for your account.") }}<br>
  {{ _("If you did not request to reset your password, ignore this email and the link will expire on its own.") }}
</p>

<p>
  <a href="{{ protocol }}://{{ domain }}{% url 'password_reset_confirm' uidb64=uid token=token %}"
     style="display:inline-block; padding: 12px 10px; margin: 10px 0; background-color: #4caf50; text-decoration: none;">
    <span style="color: #FFFFFF; text-transform: uppercase">{{ _("Set new password") }}</span>
  </a>
</p>

<p>
  {{ _("Your username, in case you've forgotten:") }} <b>{{ user.get_username }}</b><br>
  {{ _("Thanks for using our site!") }}<br>
  {% blocktrans %}The {{ site_name }} team{% endblocktrans %}
</p>
