<div class="paper-select2-filter paper-filter">
  <p class="paper-filter__title mb-1">{{ title|capfirst }}</p>

  <select name="{{ spec.parameter_name }}" id="filter-{{ spec.parameter_name }}" class="custom-select">
    {% for choice in choices %}
      <option value="{{ choice.value }}" {{ choice.selected|yesno:' selected="selected",' }}>{{ choice.display }}</option>
    {% endfor %}
  </select>
</div>