"use strict";(self.webpackChunkpaper_admin=self.webpackChunkpaper_admin||[]).push([[8101],{8420:(t,e,r)=>{var o,p,n,i,c=r(1924),a=r(3695)();if(a){o=c("Object.prototype.hasOwnProperty"),p=c("RegExp.prototype.exec"),n={};var f=function(){throw n};i={toString:f,valueOf:f},"symbol"==typeof Symbol.toPrimitive&&(i[Symbol.toPrimitive]=f)}var u=c("Object.prototype.toString"),y=Object.getOwnPropertyDescriptor;t.exports=a?function(t){if(!t||"object"!=typeof t)return!1;var e=y(t,"lastIndex");if(!(e&&o(e,"value")))return!1;try{p(t,i)}catch(t){return t===n}}:function(t){return!(!t||"object"!=typeof t&&"function"!=typeof t)&&"[object RegExp]"===u(t)}}}]);
//# sourceMappingURL=npm.is-regex.e3ac0df9778057c900c9.js.map