.multi-wrapper{border:1px solid #ccc;border-radius:3px;overflow:hidden;width:100%}.multi-wrapper .non-selected-wrapper,.multi-wrapper .selected-wrapper{box-sizing:border-box;display:inline-block;height:200px;overflow-y:scroll;padding:10px;vertical-align:top;width:50%}.multi-wrapper .non-selected-wrapper{background:#fafafa;border-right:1px solid #ccc}.multi-wrapper .selected-wrapper{background:#fff}.multi-wrapper .header{color:#4f4f4f;cursor:default;font-weight:700;margin-bottom:5px;padding:5px 10px}.multi-wrapper .item{cursor:pointer;display:block;padding:5px 10px}.multi-wrapper .item:hover{background:#ececec;border-radius:2px}.multi-wrapper .item-group{padding:5px 10px}.multi-wrapper .item-group .group-label{display:block;font-size:.875rem;opacity:.5;padding:5px 0}.multi-wrapper .search-input{border:0;border-bottom:1px solid #ccc;border-radius:0;box-sizing:border-box;display:block;font-size:1em;margin:0;outline:0;padding:10px 20px;width:100%}.multi-wrapper .non-selected-wrapper .item.selected{opacity:.5}.multi-wrapper .non-selected-wrapper .item.disabled,.multi-wrapper .selected-wrapper .item.disabled{opacity:.5;text-decoration:line-through}.multi-wrapper .non-selected-wrapper .item.disabled:hover,.multi-wrapper .selected-wrapper .item.disabled:hover{background:inherit;cursor:inherit}