{% extends "admin/base_site.html" %}


{% block content_title %}
  <h1>
    {{ _("You are now logged out") }}
  </h1>
{% endblock %}


{% block content %}
  <p>
    {{ _("Thanks for spending some quality time with the Web site today.") }}
  </p>

  <p>
    <a href="{% url 'admin:index' %}" class="btn btn-sm btn-outline-info">
      {{ _("Log in again") }}
    </a>
  </p>
{% endblock %}
