"use strict";(self.webpackChunkpaper_admin=self.webpackChunkpaper_admin||[]).push([[1746],{2636:(t,e,r)=>{var o=Object.prototype.toString;if(r(1405)()){var n=Symbol.prototype.toString,p=/^Symbol\(.*\)$/;t.exports=function(t){if("symbol"==typeof t)return!0;if("[object Symbol]"!==o.call(t))return!1;try{return function(t){return"symbol"==typeof t.valueOf()&&p.test(n.call(t))}(t)}catch(t){return!1}}}else t.exports=function(t){return!1}}}]);
//# sourceMappingURL=npm.is-symbol.6055bb5bed4241d4a22e.js.map