"use strict";(self.webpackChunkpaper_admin=self.webpackChunkpaper_admin||[]).push([[7223],{1434:(r,t,e)=>{var n=e(2584);if(e(1405)()||e(5419)()){var o=Symbol.iterator;r.exports=function(r){return null!=r&&void 0!==r[o]?r[o]():n(r)?Array.prototype[o].call(r):void 0}}else{var i=e(5826),a=e(9981),u=e(210),p=u("%Map%",!0),f=u("%Set%",!0),s=e(1924),v=s("Array.prototype.push"),c=s("String.prototype.charCodeAt"),l=s("String.prototype.slice"),y=function(r){var t=0;return{next:function(){var e,n=t>=r.length;return n||(e=r[t],t+=1),{done:n,value:e}}}},d=function(r,t){if(i(r)||n(r))return y(r);if(a(r)){var e=0;return{next:function(){var t=function(r,t){if(t+1>=r.length)return t+1;var e=c(r,t);if(e<55296||e>56319)return t+1;var n=c(r,t+1);return n<56320||n>57343?t+1:t+2}(r,e),n=l(r,e,t);return e=t,{done:t>r.length,value:n}}}}return t&&void 0!==r["_es6-shim iterator_"]?r["_es6-shim iterator_"]():void 0};if(p||f){var h=e(8379),_=e(9572),S=s("Map.prototype.forEach",!0),m=s("Set.prototype.forEach",!0);if("undefined"==typeof process||!process.versions||!process.versions.node)var x=s("Map.prototype.iterator",!0),g=s("Set.prototype.iterator",!0),M=function(r){var t=!1;return{next:function(){try{return{done:t,value:t?void 0:r.next()}}catch(r){return t=!0,{done:!0,value:void 0}}}}};var k=s("Map.prototype.@@iterator",!0)||s("Map.prototype._es6-shim iterator_",!0),b=s("Set.prototype.@@iterator",!0)||s("Set.prototype._es6-shim iterator_",!0);r.exports=function(r){return function(r){if(h(r)){if(x)return M(x(r));if(k)return k(r);if(S){var t=[];return S(r,(function(r,e){v(t,[e,r])})),y(t)}}if(_(r)){if(g)return M(g(r));if(b)return b(r);if(m){var e=[];return m(r,(function(r){v(e,r)})),y(e)}}}(r)||d(r)}}else r.exports=function(r){if(null!=r)return d(r,!0)}}}}]);
//# sourceMappingURL=npm.es-get-iterator.5fefc5dcbb4d72a1584e.js.map