"use strict";(self.webpackChunkpaper_admin=self.webpackChunkpaper_admin||[]).push([[6737],{138:(e,t,r)=>{r(8118)();var n=r(5423),i=r(3633),o=r(8330),a=r(4770),l=r(210),s=r(5559),u=s(l("%Promise.all%")),c=s(l("%Promise.reject%"));e.exports=function(e){var t=this;if("Object"!==i(t))throw new TypeError("`this` value must be an object");var r=o(e);return u(t,a(r,(function(e){var r=n(t,e);try{return r.then((function(e){return{status:"fulfilled",value:e}}),(function(e){return{status:"rejected",reason:e}}))}catch(e){return c(t,e)}})))}},9392:(e,t,r)=>{var n=r(5559),i=r(4289),o=r(8118),a=r(138),l=r(2295),s=r(1105);o();var u=n(l()),c=function(e){return u(void 0===this?Promise:this,e)};i(c,{getPolyfill:l,implementation:a,shim:s}),e.exports=c},2295:(e,t,r)=>{var n=r(8118),i=r(138);e.exports=function(){return n(),"function"==typeof Promise.allSettled?Promise.allSettled:i}},8118:e=>{e.exports=function(){if("function"!=typeof Promise)throw new TypeError("`Promise.allSettled` requires a global `Promise` be available.")}},1105:(e,t,r)=>{var n=r(8118),i=r(2295),o=r(4289);e.exports=function(){n();var e=i();return o(Promise,{allSettled:e},{allSettled:function(){return Promise.allSettled!==e}}),e}}}]);
//# sourceMappingURL=npm.promise.allsettled.34328c0974186cb1e95c.js.map