{% extends "admin/base_site.html" %}


{% block breadcrumb_items %}
  <li class="breadcrumb-item active" aria-current="page">
    {{ _("Password change") }}
  </li>
{% endblock breadcrumb_items %}


{% block content_title %}
  <h1>
    {{ title }}
  </h1>
{% endblock %}


{% block content %}
  <p class="paper-message paper-message--success">
    {{ _("Your password has been set. You may go ahead and log in now.") }}
  </p>

  <a href="{% url 'admin:index' %}" class="btn btn-success">
    {{ _("Go to dashboard") }}
  </a>
{% endblock %}
