{% extends 'admin/change_list_results.html' %}


{% block table_classes %}{{ block.super }} paper-table--tree{% endblock %}

{% block result_header %}
  <th scope="col" {{ header.class_attrib }}>
    {{ header.text|capfirst }}
  </th>
{% endblock %}
