"use strict";(self.webpackChunkpaper_admin=self.webpackChunkpaper_admin||[]).push([[9312],{7453:(r,t,a)=>{var p=a(6430),e=a(581),n=a(1146),o=a(1391),i=a(4458),u=a(1787),s=a(3306),y=a(821),c=a(6846),l=a(1924),f=a(9981),m=Object("a"),v="a"!==m[0]||!(0 in m),h=l("String.prototype.split");r.exports=function(r){var t,a=y(this),l=v&&f(a)?h(a,""):a,m=s(l.length);if(!u(r))throw new TypeError("Array.prototype.map callback must be a function");arguments.length>1&&(t=arguments[1]);for(var b=p(a,m),k=0;k<m;){var A=c(k),g=i(a,A);if(g){var w=o(a,A),x=e(r,t,[w,k,a]);n(b,A,x)}k+=1}return b}},4770:(r,t,a)=>{var p=a(4289),e=a(9619),n=a(1924),o=a(7453),i=a(7373),u=i(),s=a(2717),y=n("Array.prototype.slice"),c=function(r,t){return e(r),u.apply(r,y(arguments,1))};p(c,{getPolyfill:i,implementation:o,shim:s}),r.exports=c},7373:(r,t,a)=>{var p=a(2868),e=a(7453);r.exports=function(){var r=Array.prototype.map;return p(r)?r:e}},2717:(r,t,a)=>{var p=a(4289),e=a(7373);r.exports=function(){var r=e();return p(Array.prototype,{map:r},{map:function(){return Array.prototype.map!==r}}),r}}}]);
//# sourceMappingURL=npm.array.prototype.map.550ac33ddb738bd01a7f.js.map