<div class="custom-control custom-checkbox user-select-none">
  {% include "django/forms/widgets/input.html" %}
  <label class="custom-control-label" for="{{ widget.attrs.id }}">{{ widget.label }}</label>
</div>
